AndroidManifestPatchResult enum

Outcome of trying to inject the Superwall activity into a manifest.

Inheritance
Available extensions

Values

added → const AndroidManifestPatchResult

Activity was inserted; PatchedManifest.content is the new XML.

alreadyRegistered → const AndroidManifestPatchResult

Activity is already present; the manifest was left untouched.

malformedManifest → const AndroidManifestPatchResult

The manifest didn't have an <application> opening tag we could find, so we left it untouched and the caller should print a manual hint.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AndroidManifestPatchResult>
A constant List of the values in this enum, in order of their declaration.